Class: Google::Apis::AgentidentitycredentialsV1::AgentIdentityCredentialsService
- Inherits:
-
Core::BaseService
- Object
- Core::BaseService
- Google::Apis::AgentidentitycredentialsV1::AgentIdentityCredentialsService
- Defined in:
- lib/google/apis/agentidentitycredentials_v1/service.rb
Overview
Agent Identity Credentials API
agentidentitycredentials.googleapis.com API.
Constant Summary collapse
- DEFAULT_ENDPOINT_TEMPLATE =
"https://agentidentitycredentials.$UNIVERSE_DOMAIN$/"
Instance Attribute Summary collapse
-
#key ⇒ String
API key.
-
#quota_user ⇒ String
Available to use for quota purposes for server-side applications.
Instance Method Summary collapse
-
#finalize_project_location_auth_provider_credential(auth_provider, google_cloud_agentidentitycredentials_v1_finalize_credentials_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AgentidentitycredentialsV1::GoogleCloudAgentidentitycredentialsV1FinalizeCredentialsResponse
Finalizes the credentials after a successful consent flow.
-
#initialize ⇒ AgentIdentityCredentialsService
constructor
A new instance of AgentIdentityCredentialsService.
-
#retrieve_project_location_auth_provider_credential(auth_provider, google_cloud_agentidentitycredentials_v1_retrieve_credentials_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AgentidentitycredentialsV1::GoogleCloudAgentidentitycredentialsV1RetrieveCredentialsResponse
Retrieves authorization credentials for an authprovider, or indicates what action needs to be taken to obtain credentials.
Constructor Details
#initialize ⇒ AgentIdentityCredentialsService
Returns a new instance of AgentIdentityCredentialsService.
47 48 49 50 51 52 |
# File 'lib/google/apis/agentidentitycredentials_v1/service.rb', line 47 def initialize super(DEFAULT_ENDPOINT_TEMPLATE, '', client_name: 'google-apis-agentidentitycredentials_v1', client_version: Google::Apis::AgentidentitycredentialsV1::GEM_VERSION) @batch_path = 'batch' end |
Instance Attribute Details
#key ⇒ String
Returns API key. Your API key identifies your project and provides you with API access, quota, and reports. Required unless you provide an OAuth 2.0 token.
40 41 42 |
# File 'lib/google/apis/agentidentitycredentials_v1/service.rb', line 40 def key @key end |
#quota_user ⇒ String
Returns Available to use for quota purposes for server-side applications. Can be any arbitrary string assigned to a user, but should not exceed 40 characters.
45 46 47 |
# File 'lib/google/apis/agentidentitycredentials_v1/service.rb', line 45 def quota_user @quota_user end |
Instance Method Details
#finalize_project_location_auth_provider_credential(auth_provider, google_cloud_agentidentitycredentials_v1_finalize_credentials_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AgentidentitycredentialsV1::GoogleCloudAgentidentitycredentialsV1FinalizeCredentialsResponse
Finalizes the credentials after a successful consent flow.
76 77 78 79 80 81 82 83 84 85 86 |
# File 'lib/google/apis/agentidentitycredentials_v1/service.rb', line 76 def finalize_project_location_auth_provider_credential(auth_provider, google_cloud_agentidentitycredentials_v1_finalize_credentials_request_object = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1/{+authProvider}/credentials:finalize', ) command.request_representation = Google::Apis::AgentidentitycredentialsV1::GoogleCloudAgentidentitycredentialsV1FinalizeCredentialsRequest::Representation command.request_object = google_cloud_agentidentitycredentials_v1_finalize_credentials_request_object command.response_representation = Google::Apis::AgentidentitycredentialsV1::GoogleCloudAgentidentitycredentialsV1FinalizeCredentialsResponse::Representation command.response_class = Google::Apis::AgentidentitycredentialsV1::GoogleCloudAgentidentitycredentialsV1FinalizeCredentialsResponse command.params['authProvider'] = auth_provider unless auth_provider.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#retrieve_project_location_auth_provider_credential(auth_provider, google_cloud_agentidentitycredentials_v1_retrieve_credentials_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AgentidentitycredentialsV1::GoogleCloudAgentidentitycredentialsV1RetrieveCredentialsResponse
Retrieves authorization credentials for an authprovider, or indicates what
action needs to be taken to obtain credentials. If the token field in the
response is populated, credential retrieval was successful. If one of the
fields in the status oneof is populated, further action is required to
obtain credentials, such as redirecting the user for consent. View comments on
RetrieveCredentialsResponse for more information.
115 116 117 118 119 120 121 122 123 124 125 |
# File 'lib/google/apis/agentidentitycredentials_v1/service.rb', line 115 def retrieve_project_location_auth_provider_credential(auth_provider, google_cloud_agentidentitycredentials_v1_retrieve_credentials_request_object = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1/{+authProvider}/credentials:retrieve', ) command.request_representation = Google::Apis::AgentidentitycredentialsV1::GoogleCloudAgentidentitycredentialsV1RetrieveCredentialsRequest::Representation command.request_object = google_cloud_agentidentitycredentials_v1_retrieve_credentials_request_object command.response_representation = Google::Apis::AgentidentitycredentialsV1::GoogleCloudAgentidentitycredentialsV1RetrieveCredentialsResponse::Representation command.response_class = Google::Apis::AgentidentitycredentialsV1::GoogleCloudAgentidentitycredentialsV1RetrieveCredentialsResponse command.params['authProvider'] = auth_provider unless auth_provider.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |