Class: Google::Apis::AgentidentitycredentialsV1::GoogleCloudAgentidentitycredentialsV1RetrieveCredentialsRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/agentidentitycredentials_v1/classes.rb,
lib/google/apis/agentidentitycredentials_v1/representations.rb,
lib/google/apis/agentidentitycredentials_v1/representations.rb

Overview

Request message for RetrieveCredentials.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAgentidentitycredentialsV1RetrieveCredentialsRequest

Returns a new instance of GoogleCloudAgentidentitycredentialsV1RetrieveCredentialsRequest.



128
129
130
# File 'lib/google/apis/agentidentitycredentials_v1/classes.rb', line 128

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#continue_uriString

Optional. The URI to redirect the user to after consent is completed. This field is required for authproviders using the 3-legged OAuth flow. For other authprovider types, this field is unused but not rejected. Corresponds to the JSON property continueUri

Returns:

  • (String)


108
109
110
# File 'lib/google/apis/agentidentitycredentials_v1/classes.rb', line 108

def continue_uri
  @continue_uri
end

#force_refresh_tokenString

Optional. Input only. Set this field only if the previous token was expired or invalid. This value must be the full, previously returned token string. Will trigger a refresh of the access token with a stored refresh token, if possible, or a new consent flow. Corresponds to the JSON property forceRefreshToken

Returns:

  • (String)


116
117
118
# File 'lib/google/apis/agentidentitycredentials_v1/classes.rb', line 116

def force_refresh_token
  @force_refresh_token
end

#scopesArray<String>

Optional. The OAuth scopes required for this access. Corresponds to the JSON property scopes

Returns:

  • (Array<String>)


121
122
123
# File 'lib/google/apis/agentidentitycredentials_v1/classes.rb', line 121

def scopes
  @scopes
end

#user_idString

Required. The identity of the end user. Corresponds to the JSON property userId

Returns:

  • (String)


126
127
128
# File 'lib/google/apis/agentidentitycredentials_v1/classes.rb', line 126

def user_id
  @user_id
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



133
134
135
136
137
138
# File 'lib/google/apis/agentidentitycredentials_v1/classes.rb', line 133

def update!(**args)
  @continue_uri = args[:continue_uri] if args.key?(:continue_uri)
  @force_refresh_token = args[:force_refresh_token] if args.key?(:force_refresh_token)
  @scopes = args[:scopes] if args.key?(:scopes)
  @user_id = args[:user_id] if args.key?(:user_id)
end