Class: Google::Apis::AgentidentitycredentialsV1::GoogleCloudAgentidentitycredentialsV1RetrieveCredentialsResponse
- Inherits:
-
Object
- Object
- Google::Apis::AgentidentitycredentialsV1::GoogleCloudAgentidentitycredentialsV1RetrieveCredentialsResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/agentidentitycredentials_v1/classes.rb,
lib/google/apis/agentidentitycredentials_v1/representations.rb,
lib/google/apis/agentidentitycredentials_v1/representations.rb
Overview
Response message for RetrieveCredentials. Contains the access tokens and related artifacts.
Instance Attribute Summary collapse
-
#consent_rejected ⇒ Google::Apis::AgentidentitycredentialsV1::GoogleCloudAgentidentitycredentialsV1ConsentRejected
Indicates the user has rejected the permission delegation or cancelled the request.
-
#pending ⇒ Google::Apis::AgentidentitycredentialsV1::GoogleCloudAgentidentitycredentialsV1Pending
Indicates that the credential retrieval is pending.
-
#success ⇒ Google::Apis::AgentidentitycredentialsV1::GoogleCloudAgentidentitycredentialsV1Success
Message indicating successful retrieval of credentials.
-
#uri_consent_required ⇒ Google::Apis::AgentidentitycredentialsV1::GoogleCloudAgentidentitycredentialsV1UriConsentRequired
Indicates that the user must visit the provided URI to consent to delegate permission to the agent to act on their behalf.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAgentidentitycredentialsV1RetrieveCredentialsResponse
constructor
A new instance of GoogleCloudAgentidentitycredentialsV1RetrieveCredentialsResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAgentidentitycredentialsV1RetrieveCredentialsResponse
Returns a new instance of GoogleCloudAgentidentitycredentialsV1RetrieveCredentialsResponse.
170 171 172 |
# File 'lib/google/apis/agentidentitycredentials_v1/classes.rb', line 170 def initialize(**args) update!(**args) end |
Instance Attribute Details
#consent_rejected ⇒ Google::Apis::AgentidentitycredentialsV1::GoogleCloudAgentidentitycredentialsV1ConsentRejected
Indicates the user has rejected the permission delegation or cancelled the
request.
Corresponds to the JSON property consentRejected
150 151 152 |
# File 'lib/google/apis/agentidentitycredentials_v1/classes.rb', line 150 def @consent_rejected end |
#pending ⇒ Google::Apis::AgentidentitycredentialsV1::GoogleCloudAgentidentitycredentialsV1Pending
Indicates that the credential retrieval is pending. The caller should retry
the RetrieveCredentials request after some time.
Corresponds to the JSON property pending
156 157 158 |
# File 'lib/google/apis/agentidentitycredentials_v1/classes.rb', line 156 def pending @pending end |
#success ⇒ Google::Apis::AgentidentitycredentialsV1::GoogleCloudAgentidentitycredentialsV1Success
Message indicating successful retrieval of credentials.
Corresponds to the JSON property success
161 162 163 |
# File 'lib/google/apis/agentidentitycredentials_v1/classes.rb', line 161 def success @success end |
#uri_consent_required ⇒ Google::Apis::AgentidentitycredentialsV1::GoogleCloudAgentidentitycredentialsV1UriConsentRequired
Indicates that the user must visit the provided URI to consent to delegate
permission to the agent to act on their behalf. The caller can either poll the
RetrieveCredentials method, or await the /ValidateUserId callback
Corresponds to the JSON property uriConsentRequired
168 169 170 |
# File 'lib/google/apis/agentidentitycredentials_v1/classes.rb', line 168 def @uri_consent_required end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
175 176 177 178 179 180 |
# File 'lib/google/apis/agentidentitycredentials_v1/classes.rb', line 175 def update!(**args) @consent_rejected = args[:consent_rejected] if args.key?(:consent_rejected) @pending = args[:pending] if args.key?(:pending) @success = args[:success] if args.key?(:success) @uri_consent_required = args[:uri_consent_required] if args.key?(:uri_consent_required) end |