Class: Google::Apis::AgentidentitycredentialsV1::GoogleCloudAgentidentitycredentialsV1UriConsentRequired
- Inherits:
-
Object
- Object
- Google::Apis::AgentidentitycredentialsV1::GoogleCloudAgentidentitycredentialsV1UriConsentRequired
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/agentidentitycredentials_v1/classes.rb,
lib/google/apis/agentidentitycredentials_v1/representations.rb,
lib/google/apis/agentidentitycredentials_v1/representations.rb
Overview
Indicates that the user must visit the provided URI to consent to delegate
permission to the agent to act on their behalf. The caller can either poll the
RetrieveCredentials method, or await the /ValidateUserId callback
Instance Attribute Summary collapse
-
#authorization_uri ⇒ String
Output only.
-
#consent_nonce ⇒ String
Output only.
-
#uid ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAgentidentitycredentialsV1UriConsentRequired
constructor
A new instance of GoogleCloudAgentidentitycredentialsV1UriConsentRequired.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAgentidentitycredentialsV1UriConsentRequired
Returns a new instance of GoogleCloudAgentidentitycredentialsV1UriConsentRequired.
259 260 261 |
# File 'lib/google/apis/agentidentitycredentials_v1/classes.rb', line 259 def initialize(**args) update!(**args) end |
Instance Attribute Details
#authorization_uri ⇒ String
Output only. The URL where the user should be redirected to grant consent.
This will always be present.
Corresponds to the JSON property authorizationUri
243 244 245 |
# File 'lib/google/apis/agentidentitycredentials_v1/classes.rb', line 243 def @authorization_uri end |
#consent_nonce ⇒ String
Output only. A one-time, randomly generated value that validates the entire
consent flow is handled by a single user, avoiding CSRF attacks. It must be
submitted with the FinalizeCredentials request to complete the OAuth exchange.
This will always be present. Implemented per https://www.rfc-editor.org/rfc/
rfc6819#section-5.3.5
Corresponds to the JSON property consentNonce
252 253 254 |
# File 'lib/google/apis/agentidentitycredentials_v1/classes.rb', line 252 def @consent_nonce end |
#uid ⇒ String
Output only. The unique ID of the credentials retrieval operation.
Corresponds to the JSON property uid
257 258 259 |
# File 'lib/google/apis/agentidentitycredentials_v1/classes.rb', line 257 def uid @uid end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
264 265 266 267 268 |
# File 'lib/google/apis/agentidentitycredentials_v1/classes.rb', line 264 def update!(**args) @authorization_uri = args[:authorization_uri] if args.key?(:authorization_uri) @consent_nonce = args[:consent_nonce] if args.key?(:consent_nonce) @uid = args[:uid] if args.key?(:uid) end |